# BetterSanic
This project adds discord.py-like cogs and extensions to sanic. 
This project was made for my own use and i will only be updating this if i need to add something to it or fix a bug that is annoying me.
Although I may once in a while look into the issues and fix some, though this will be rare.